'use strict';
/* exported MockContactsListObj */

var MockContactsListObj = {
    init: function() {},
    load: function() {},
    refresh: function() {},
    refreshFb: function() {},
    getContactById: function() {},
    getAllContacts: function() {},
    handleClick: function() {},
    remove: function() {},
    loaded: true,
    clearClickHandlers: function() {},
    setOrderByLastName: function() {},
    initAlphaScroll: function() {},
    isSelecting: false
};
